============
Installation
============

At the command line::

    $ easy_install drf-cached-instances

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv drf-cached-instances
    $ pip install drf-cached-instances